#include <msp430.h>

void initCS(void)
{
    FRCTL0 = FRCTLPW | NWAITS_2 ;

    P2SEL1 |= BIT6 | BIT7;                       // P2.6~P2.7: crystal pins
    do
    {
        CSCTL7 &= ~(XT1OFFG | DCOFFG);           // Clear XT1 and DCO fault flag
        SFRIFG1 &= ~OFIFG;
    } while (SFRIFG1 & OFIFG);                   // Test oscillator fault flag

    __bis_SR_register(SCG0);                     // disable FLL
    CSCTL3 |= SELREF__XT1CLK;                    // Set XT1 as FLL reference source
    CSCTL0 = 0;                                  // clear DCO and MOD registers
    CSCTL1 |= DCORSEL_7;                         // Set DCO = 24MHz
    CSCTL2 = FLLD_0 + 731;                       // DCOCLKDIV = 24MHz
    __delay_cycles(3);
    __bic_SR_register(SCG0);                     // enable FLL
    while(CSCTL7 & (FLLUNLOCK0 | FLLUNLOCK1));   // FLL locked

    CSCTL4 = SELMS__DCOCLKDIV | SELA__XT1CLK;   // set XT1 (~32768Hz) as ACLK source, ACLK = 32768Hz
                                                 // default DCOCLKDIV as MCLK and SMCLK source

}
#define FREQ_500K   48
#define FREQ_600K   40
#define FREQ_700K   34
#define FREQ        FREQ_600K
int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;                                   // Stop WDT

    initCS();

    P1DIR |= BIT6;
    P1SEL1 |=  BIT6;        // P1.6/TB0.1 output

    // Disable the GPIO power-on default high-impedance mode to activate
    // previously configured port settings
    PM5CTL0 &= ~LOCKLPM5;

    // Timer will toggle output independent of CPU
    TB0CCTL1 |= OUTMOD_7;
    TB0CCR0 = FREQ;
    TB0CCR1 = FREQ >> 1;
    TB0CTL = TBSSEL__SMCLK | MC__UP;             // SMCLK, UP mode

    // CPU enters while loop
    // can sleep all the time or do other tasks
    while(1)
    {
        __bis_SR_register(LPM0_bits);          // Enter LPM0 w/ interrupt
        __no_operation();                            // For debug

    }

}